;*******************************************************************************
;  MSP430x54x Demo - Bank Erase from a Block while Executing Code from Another
;                    Block.
;
;  Description: This program first writes to Bank 1 from 0x10000 to 0x10100.
;  Then a bank erase is done on Bank 1. During Bank erase, code is still
;  executing from Bank 0 by toggling P1.0. Toggling can only be seen by using
;  an oscilloscope.
;  RESET the device to re-execute code. This is implemented to prevent
;  stressing of Flash unintentionally.
;  ACLK = REFO = 32kHz, MCLK = SMCLK = default DCO 1048576Hz
;
;               MSP430x54x
;            -----------------
;        /|\|              XIN|-
;         | |                 |
;         --|RST          XOUT|-
;           |                 |
;           |             P1.0|- Probe with oscilloscope
;
;   M. Morales
;   Texas Instruments Inc.
;   February 2009
;   Built with Code Composer Essentials v3.x
;*******************************************************************************

    .cdecls C,LIST,"msp430x54x.h"

;-------------------------------------------------------------------------------
value    .equ    R4 
;-------------------------------------------------------------------------------
            .global _main 
            .text                           ; Assemble to Flash memory
;-------------------------------------------------------------------------------
_main
RESET       mov.w   #0x5C00,SP              ; Initialize stackpointer
StopWDT     mov.w   #WDTPW+WDTHOLD,&WDTCTL  ; Stop WDT

            bis.b   #0x01,&P1DIR            ; Set P1.0 as output
            bic.b   #0x01,&P1OUT            ; clear P1.0
            mov.w   #0,value                ; SET BREAKPOINT HERE
            call    #wrt_Bank1              ; Write to Bank 1
            call    #erase_Seg              ; Call erase function
loop_L1     bit.w   #BUSY,&FCTL3            ; Check for erase completion
            jnc     exit_Loop               ; Exit if erase is done
            xor.b   #0x01,&P1OUT            ; toggle LED
            jmp     loop_L1                 ;

exit_Loop   bic.b   #0x01,&P1OUT            ; clear P1.0
Mainloop    jmp     Mainloop                ; Loop forever, SET BREAKPOINT HERE
;-------------------------------------------------------------------------------
erase_Seg ;  Copy Seg C to Seg D, R5 used as working reg.
;-------------------------------------------------------------------------------
            dint                            ; 5xx Workaround: Disable global
                                            ; interrupt while erasing. Re-Enable
                                            ; GIE if needed
            mov.w   #FWKEY,&FCTL3           ; Clear Lock bit
            mov.w   #FWKEY+MERAS,&FCTL1     ; Set Bank Erase bit
            movx.w  #0,&0x10000             ; Dummy erase byte
            mov.w   #FWKEY+LOCK,&FCTL3      ; Set LOCK bit
            ret
;-------------------------------------------------------------------------------
wrt_Bank1 ; Input = value, holds value to write to Seg C, R5 used as working reg
;-------------------------------------------------------------------------------
            movx.a  #0x10000,R5             ; Initialize Flash pointer
            mov.w   #FWKEY,&FCTL3           ; Clear Lock bit
            mov.w   #FWKEY+WRT,&FCTL1       ; Set WRT bit for write operation
wrt_Bnk1_L1 mov.w   value,0(R5)             ; Write a word to flash
            incdx.a R5
            inc.w   value
            cmpx.a  #0x10100,R5
            jne     wrt_Bnk1_L1
            mov.w   #FWKEY,&FCTL1           ; Clear WRT bit
            mov.w   #FWKEY+LOCK,&FCTL3      ; Set LOCK bit
            ret                             ;
;-------------------------------------------------------------------------------
                  ; Interrupt Vectors
;-------------------------------------------------------------------------------
            .sect   ".reset"                ; POR, ext. Reset
            .short  RESET
            .end